/*===========================================================================*/
/*
 * This file is part of
 * libogg++java - the java bindings for libogg++,
 *                a c++ library for the Ogg transport format
 *
 * Copyright (C) 2007, 2008   Elaine Tsiang YueLien
 * libogg++java is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see http://www.gnu.org/license,
 * or write to the
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301, USA
 *
 *===========================================================================*/
/** @file JniOgg.i                                                           *
 *                                                                           *
 *  swig conversion specification for Ogg                                    *
 *                                                                           */
/*===========================================================================*/
%module(directors="1") JniOgg
%{
#include <Ogg/Ogg.H>
#include <Ogg/Exception.H>
#include <Ogg/Transport.H>
#include <Ogg/Logical.H>
%}

%typemap(javafinalize) SWIGTYPE "" 

%include "Cni/Ogg.H"

%include <std_string.i>

%rename("orEq") operator |=;
%rename("test") operator [];
%rename("describe") operator ();

%{
    /* Ogg::Exception and derived are deemed severe enough to
     * make impossible the continuing reading or writing of an Ogg stream
     */
%}
%include "Cni/Exception.H"
     
%exception %{
try {
     $action
     } catch (Ogg::Exception & e)
      {
        jclass excep = jenv->FindClass("java/lang/Exception");
	if (excep)
	 jenv->ThrowNew(excep, e.what());
  	return $null;
	}
       catch (...)
      {
        SWIG_JavaThrowException(jenv, SWIG_JavaRuntimeException,
        			"C++ non Ogg::Exception thrown");
  	return $null;
	}
%}


SWIG_JAVABODY_METHODS(public, public, Ogg::Transport, Ogg::Page, Ogg::Logical, Ogg::Reader, Ogg::Writer, Ogg::Packet)

%include <arrays_java.i>
%apply signed char[] {signed char *};

%feature("director") Transport;
%nodefaultctor Ogg::Page;

%include "Cni/Transport.H"

%rename("nextPacket") operator ++;
%rename("relativeSeek") operator +=;
%rename("seek") operator =;
%feature("director") Logical;
%nodefaultctor Ogg::Packet;
%nodefaultctor Ogg::Writer;
%nodefaultctor Ogg::Reader;
// The java side needs to delete
// Writer and Reader objects
// to execute last packet rites
%newobject Ogg::Logical::writer();
%newobject Ogg::Logical::reader();
%include "Cni/Logical.H"

%{
namespace Ogg
{
  typedef Logical::Writer Writer;
  typedef Logical::Reader Reader;
}
%}
